@@ -40,6 +40,7 @@
 #endif
 
 #include <errno.h>
+#include <stdio.h>
 
 NAMESPACE_UCOMMON
 
@@ -73,6 +74,7 @@ protected:
 #endif
 	int		error;
 
+public:
 #ifdef	_MSWINDOWS_
 	static int remapError(void);
 #else
@@ -80,7 +82,6 @@ protected:
 		{return errno;};
 #endif
 
-public:
 	/**
 	 * Enumerated file access modes.
 	 */
@@ -453,6 +454,35 @@ public:
 	 * @return address of symbol or NULL if not found.
 	 */
 	static void *find(fsys& module, const char *symbol);
+
+	/**
+	 * A convenience method to standardize file printf.  This mostly
+	 * is to assure some consistency in coding practices and return values.
+	 * @param file to write to.
+	 * @param format of printf string.
+	 * @return number of bytes written.
+	 */
+	static size_t printf(FILE *file, const char *format, ...) __PRINTF(2, 3);
+	
+	/**
+	 * A convenience method to standardize writing strings.  This is mostly
+	 * to assure some consistency with other common code.
+	 * @param file to write to.
+	 * @param string to write.
+	 * @return number of bytes written.
+	 */
+	static size_t writes(FILE *file, const char *string);
+
+	/**
+	 * A realine method for files.  This is mostly to offer behavior similar
+	 * to other readln methods, which can accept either "\n" or "\r\n" line
+	 * termination, and strip the eol from the buffer.
+	 * @param file to read from.
+	 * @param address of buffer to save string.
+	 * @param size of buffer.
+	 * @return number of bytes actually retrieved.  0 may indicate EOF.
+	 */
+	static size_t readln(FILE *file, char *address, size_t size);
 };
 	
 /**
