@@ -164,6 +164,14 @@ public:
 	 */
 	inline error_t err(void)
 		{return error;};
+
+	/**
+	 * Create 36 character traditional version 1 uuid.
+	 * @param string to write uuid into, must be 37 bytes or more.
+	 */
+	static void uuid(char *string);
+
+	static String uuid(void);
 };
 
 /**
@@ -400,6 +408,12 @@ public:
 
 	const char *c_str(void);
 
+	inline String str(void)
+		{return String(c_str());};
+
+	inline operator String()
+		{return String(c_str());};
+
 	void set(const char *id);
 
 	inline void operator=(const char *id)
@@ -426,6 +440,10 @@ public:
 	 * @return true if supported, false if not.
 	 */
 	static bool is(const char *name);
+
+	static void uuid(char *string, const char *name, const unsigned char *ns = NULL);
+
+	static String uuid(const char *name, const unsigned char *ns = NULL);
 };
 
 /**
@@ -503,6 +521,14 @@ public:
 	 * @return true if sufficient entropy.
 	 */
 	static bool status(void);
+
+	/**
+	 * Create 36 character random uuid string.
+	 * @param string to write uuid into, must be 37 bytes or more.
+	 */
+	static void uuid(char *string);
+
+	static String uuid(void);
 };
 
 /**
