@@ -301,6 +301,12 @@ public:
 		inline static LinkedObject *first(void)
 			{return index.begin();};
 
+		/**
+		 * Disable a option.  Might happen if argv0 name suggests an
+		 * option is no longer actively needed.
+		 */
+		void disable(void);
+
 		/**
 		 * Used to send option into derived receiver.
 		 * @param value option that was received.
@@ -502,6 +508,31 @@ public:
 	 */
 	void parse(int argc, char **argv);
 
+	/**
+	 * Get an environment variable.  This creates a local copy of the
+	 * variable in pager memory.
+	 * @param name of symbol.
+	 * @param value of symbol if not found.
+	 * @return value of symbol.
+	 */
+	const char *getenv(const char *name, const char *value = NULL);
+
+	/**
+	 * Parse and extract the argv0 filename alone.
+	 * @param argv from main.
+	 * @return argv0 simple path name.
+	 */
+	char *getargv0(char **argv);
+
+	/**
+	 * Get the argument list by parsing options, and return the remaining
+	 * file arguments.  This is used by parse, and can be fed by main by
+	 * posting ++argv.
+	 * @param argv of first option.
+	 * @return argv of non-option file list.
+	 */
+	char **getargv(char **argv);
+
 	/**
 	 * Parse shell arguments directly into a shell object.
 	 * @param args table.
